@@ -1,4 +1,6 @@
 #include <stdio.h>
+#include <string.h>
+
 #include "mrss.h"
 
 int
@@ -15,7 +17,10 @@ main (int argc, char **argv)
       return 1;
     }
 
-  ret = mrss_parse_url (argv[1], &data);
+  if (!strncmp (argv[1], "http://", 7))
+    ret = mrss_parse_url (argv[1], &data);
+  else
+    ret = mrss_parse_file (argv[1], &data);
 
   if (ret)
     {
